%define major		2
%define libname		%mklibname %{name} %{major}
%define develname	%mklibname %{name} -d

Name:		pfstools
Version:	2.0.6
Release:	%mkrel 3
Summary:	Programs for handling high-dynamic range images
Group:		Graphics/Utilities
License:	GPLv2+
URL:		http://pfstools.sourceforge.net/
Source0:	http://sourceforge.net/projects/pfstools/files/%{name}/%{version}/%{name}-%{version}.tgz
Patch3:		pfstools-2.0.4-gcc44.patch

BuildRequires:	cmake
BuildRequires:	texlive
BuildRequires:	qt4-devel
BuildRequires:	octave-devel
BuildRequires:	freeglut-devel
BuildRequires:	netpbm-devel
BuildRequires:	pkgconfig(gsl)
BuildRequires:	pkgconfig(fftw3)
BuildRequires:	pkgconfig(libtiff-4)
BuildRequires:	pkgconfig(OpenEXR)
BuildRequires:	pkgconfig(ImageMagick)
BuildRequires:	pkgconfig(gl)
BuildRequires:	pkgconfig(xi)

Obsoletes:	pfstools-gdal < 1.8.5-3


%description
pfstools is a set of command line programs for reading,
writing, manipulating and viewing high-dynamic range (HDR) images and
video frames. All programs in the package exchange data using unix
pipes and a simple generic HDR image format (pfs). The concept of the
pfstools is similar to netpbm package for low-dynamic range images.


%package -n	pfscalibration
Summary:	Scripts and programs for photometric calibration
Group:		Graphics/Utilities
Requires:	perl
Requires:	dcraw
Requires:	jhead

%description -n	pfscalibration
PFScalibration package provides an implementation of the Robertson et al. 2003
method for the photometric calibration of cameras, Mitsunaga and Nayar's
algorithm "Radiometric Self Calibration", and for the recovery of high dynamic
range (HDR) images from the set of low dynamic range (LDR) exposures.


%package -n	pfstmo
Summary:	PFS tone mapping operators
Group:		Graphics/Utilities

%description -n	pfstmo
The pfstmo package contains the implementation of state-of-the-art tone
mapping operators. The motivation here is to provide an implementation of
tone mapping operators suitable for convenient processing of both static
images and animations.


%package -n	%{libname}
Summary:	Libraries for HDR processing
Group:		System/Libraries
License:	LGPLv2+

%description -n	%{libname}
The lib(64)pfstools package contains a runtime library of functions for
handling HDR graphics files.


%package	qt
Summary:	Qt-based viewer for HDR files
Group:		Graphics/Viewers

%description	qt
The pfstools-qt package contains viewer programs based on qt4 for
viewing HDR graphics files.


%package	glview
Summary:	GL-based viewer for HDR files
Group:		Graphics/Viewers

%description	glview
The pfstools-glview package contains viewer programs based on OpenGL for
viewing HDR graphics files.


%package	exr
Summary:	EXR file import for PFS tools
Group:		Graphics/Utilities

%description	exr
The pfstools-exr package contains input and output filters for EXR files
to and from the HDR graphics file format used in pfstools.


%package	imgmagick
Summary:	ImageMagick file import for PFS tools
Group:		Graphics/Utilities

%description	imgmagick
The pfstools-imgmagick package contains input and output filters based in
ImageMagick to and from the HDR graphics file format used in pfstools.


%package	octave
Summary:	Octave interaction with PFS tools
Group:		Graphics/Utilities

%description	octave
The pfstools-octave package contains programs to process red, green and blue
channels or luminance channels in pfs stream using Octave.


%package -n	%{develname}
Summary:	Files for development with PFS tools
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}

%description -n	%{develname}
The lib(64)pfstools-devel package contains the header files and link libraries,
etc., for developing programs which can handle HDR graphics files.


%prep
%setup -q
%autopatch -p1

%build
%cmake \
	-DBUILD_SHARED_LIBS=ON \
	-DLIB_DIR=%{_lib} \
	-DWITH_OpenCV=OFF
%make_build

%install
%make_install -C build

# we don't want these
find %{buildroot} -name '*.la' -delete

# nuke unpackaged files
find %{buildroot} -name 'pfsinjpeghdr.1' -delete
find %{buildroot} -name 'pfsoutjpeghdr.1' -delete

%files
%doc AUTHORS ChangeLog README doc/faq.txt
%{_bindir}/pfsabsolute
%{_bindir}/pfscat
%{_bindir}/pfsclamp
%{_bindir}/pfscut
%{_bindir}/pfsextractchannels
%{_bindir}/pfsdisplayfunction
%{_bindir}/pfsflip
%{_bindir}/pfsgamma
%{_bindir}/pfsin
%{_bindir}/pfsindcraw
%{_bindir}/pfsinpfm
%{_bindir}/pfsinppm
%{_bindir}/pfsinrgbe
%{_bindir}/pfsintiff
%{_bindir}/pfsout
%{_bindir}/pfsouthdrhtml
%{_bindir}/pfsoutpfm
%{_bindir}/pfsoutppm
%{_bindir}/pfsoutrgbe
%{_bindir}/pfsouttiff
%{_bindir}/pfspad
%{_bindir}/pfspanoramic
%{_bindir}/pfsrotate
%{_bindir}/pfssize
%{_bindir}/pfstag
%{_bindir}/pfscolortransform
%{_bindir}/pfsretime
%{_datadir}/pfstools/hdrhtml_c_b2.csv
%{_datadir}/pfstools/hdrhtml_c_b3.csv
%{_datadir}/pfstools/hdrhtml_c_b4.csv
%{_datadir}/pfstools/hdrhtml_c_b5.csv
%{_datadir}/pfstools/hdrhtml_default_templ/
%{_datadir}/pfstools/hdrhtml_hdrlabs_templ/
%{_datadir}/pfstools/hdrhtml_t_b2.csv
%{_datadir}/pfstools/hdrhtml_t_b3.csv
%{_datadir}/pfstools/hdrhtml_t_b4.csv
%{_datadir}/pfstools/hdrhtml_t_b5.csv
%{_mandir}/man1/pfsabsolute.1.xz
%{_mandir}/man1/pfscat.1.xz
%{_mandir}/man1/pfsclamp.1.xz
%{_mandir}/man1/pfscut.1.xz
%{_mandir}/man1/pfsdisplayfunction.1.xz
%{_mandir}/man1/pfsextractchannels.1.xz
%{_mandir}/man1/pfsflip.1.xz
%{_mandir}/man1/pfsgamma.1.xz
%{_mandir}/man1/pfsin.1.xz
%{_mandir}/man1/pfsindcraw.1.xz
%{_mandir}/man1/pfsinpfm.1.xz
%{_mandir}/man1/pfsinppm.1.xz
%{_mandir}/man1/pfsinrgbe.1.xz
%{_mandir}/man1/pfsintiff.1.xz
%{_mandir}/man1/pfsout.1.xz
%{_mandir}/man1/pfsouthdrhtml.1.xz
%{_mandir}/man1/pfsoutpfm.1.xz
%{_mandir}/man1/pfsoutppm.1.xz
%{_mandir}/man1/pfsoutrgbe.1.xz
%{_mandir}/man1/pfsouttiff.1.xz
%{_mandir}/man1/pfspad.1.xz
%{_mandir}/man1/pfspanoramic.1.xz
%{_mandir}/man1/pfsrotate.1.xz
%{_mandir}/man1/pfssize.1.xz
%{_mandir}/man1/pfstag.1.xz
%{_mandir}/man1/pfscolortransform.1.xz
%{_mandir}/man1/pfsretime.1.xz

%files -n pfscalibration
%{_bindir}/dcraw2hdrgen
%{_bindir}/jpeg2hdrgen
%{_bindir}/pfshdrcalibrate
%{_bindir}/pfsinhdrgen
%{_bindir}/pfsinme
%{_bindir}/pfsplotresponse
%{_mandir}/man1/dcraw2hdrgen.1.xz
%{_mandir}/man1/jpeg2hdrgen.1.xz
%{_mandir}/man1/pfshdrcalibrate.1.xz
%{_mandir}/man1/pfsinhdrgen.1.xz
%{_mandir}/man1/pfsinme.1.xz
%{_mandir}/man1/pfsplotresponse.1.xz

%files -n pfstmo
%{_bindir}/pfstmo_reinhard05
%{_bindir}/pfstmo_pattanaik00
%{_bindir}/pfstmo_mantiuk06
%{_bindir}/pfstmo_fattal02
%{_bindir}/pfstmo_drago03
%{_bindir}/pfstmo_reinhard02
%{_bindir}/pfstmo_durand02
%{_bindir}/pfstmo_mantiuk08
%{_bindir}/pfstmo_ferradans11
%{_bindir}/pfstmo_mai11
%{_mandir}/man1/pfstmo_reinhard05.1.xz
%{_mandir}/man1/pfstmo_pattanaik00.1.xz
%{_mandir}/man1/pfstmo_mantiuk06.1.xz
%{_mandir}/man1/pfstmo_fattal02.1.xz
%{_mandir}/man1/pfstmo_drago03.1.xz
%{_mandir}/man1/pfstmo_reinhard02.1.xz
%{_mandir}/man1/pfstmo_durand02.1.xz
%{_mandir}/man1/pfstmo_mantiuk08.1.xz
%{_mandir}/man1/pfstmo_ferradans11.1.xz
%{_mandir}/man1/pfstmo_mai11.1.xz

%files -n %{libname}
%{_libdir}/libpfs.so.%{major}
%{_libdir}/libpfs.so.%{major}.*

%files qt
%{_bindir}/pfsv
%{_bindir}/pfsview
%{_mandir}/man1/pfsview.1.xz

%files glview
%{_bindir}/pfsglview
%{_mandir}/man1/pfsglview.1.xz

%files exr
%{_bindir}/pfsinexr
%{_bindir}/pfsoutexr
%{_mandir}/man1/pfsinexr.1.xz
%{_mandir}/man1/pfsoutexr.1.xz

%files imgmagick
%{_bindir}/pfsinimgmagick
%{_bindir}/pfsoutimgmagick
%{_mandir}/man1/pfsinimgmagick.1.xz
%{_mandir}/man1/pfsoutimgmagick.1.xz

%files octave
%{_bindir}/pfsoctavelum
%{_bindir}/pfsoctavergb
%{_bindir}/pfsstat
%{_libdir}/octave/*/site/oct/*/pfstools
%{_datadir}/octave/*/site/m/pfstools
%{_mandir}/man1/pfsoctavelum.1.xz
%{_mandir}/man1/pfsoctavergb.1.xz
%{_mandir}/man1/pfsstat.1.xz

%files -n %{develname}
%doc doc/pfs_format_spec.tex
%{_libdir}/libpfs.so
%{_libdir}/pkgconfig/pfs.pc
%{_includedir}/pfs


%changelog
* Sun May 28 2017 shlomif <shlomif> 2.0.6-3.mga6
+ Revision: 1105289
- rebuild / resubmit
- rebuild for new imagemagick lib major

* Wed Apr 26 2017 akien <akien> 2.0.6-1.mga6
+ Revision: 1097537
- Version 2.0.6

* Fri Dec 02 2016 eatdirt <eatdirt> 2.0.5-2.mga6
+ Revision: 1071792
- Rebuild for new octave

* Thu May 26 2016 daviddavid <daviddavid> 2.0.5-1.mga6
+ Revision: 1018850
- new version: 2.0.5
- remove merged upstream patches

* Tue Jan 26 2016 luigiwalser <luigiwalser> 2.0.4-7.mga6
+ Revision: 927868
- rebuild for gsl

* Mon Jan 11 2016 neoclust <neoclust> 2.0.4-6.mga6
+ Revision: 921462
- Fix BuildRequires

* Tue Nov 10 2015 daviddavid <daviddavid> 2.0.4-5.mga6
+ Revision: 900746
- rebuild for new octave 4.0.0

* Thu Oct 29 2015 tv <tv> 2.0.4-4.mga6
+ Revision: 896235
- BR pkgconfig(pfs)

* Fri Aug 28 2015 cjw <cjw> 2.0.4-3.mga6
+ Revision: 870404
- rebuild with gcc 5

* Fri Jul 24 2015 daviddavid <daviddavid> 2.0.4-2.mga6
+ Revision: 856988
- remove unneeded requires (as there are auto-required)

* Fri Jul 24 2015 daviddavid <daviddavid> 2.0.4-1.mga6
+ Revision: 856842
- new version: 2.0.4
- switch to cmake build
- now major is 2
- remove no more needed Patches
- add 3 Patches from Fedora
- add more BuildRequires on gsl and fftw3
- update Source URL
- obsoletes pfstools-gdal subpackage (removed upstream)
- pfscalibration and pfstmo are now part of pfstools
- update file list

* Tue Jun 23 2015 daviddavid <daviddavid> 1.8.5-2.mga6
+ Revision: 841454
- rebuild for new ImageMagick

* Tue Jan 27 2015 daviddavid <daviddavid> 1.8.5-1.mga5
+ Revision: 812448
- imported package pfstools
- based from Fedora's package
- adapt for Mageia

